A convenience utility to fit regression models more quickly in the main
internal functions for estimation, which usually require logistic regression.
Use of speedglm appears to provide roughly an order of magnitude
improvement in speed when compared to glm in custom benchmarks.
fast_glm(reg_form, data, family, ...)Object of class formula indicating the regression to
be fit.
Object of class data.frame containing the data.
Object of class family from package stats
indicating the error distribution. Appropriate options are limited to
gaussian and binomial.
Additional arguments passed to glm or speedglm.
Object of class glm or speedglm.